agentle.agents.whatsapp.models.message
======================================

.. automodule:: agentle.agents.whatsapp.models.message

   
   .. rubric:: Functions

   .. autosummary::
   
      TypedDict
   
   .. rubric:: Classes

   .. autosummary::
   
      AudioMessage
      DocumentMessage
      ImageMessage
      Message
      VideoMessage
   